**Example 1: 示例**

导出授权使用记录/历史记录

Input: 

```
tccli cwp ExportLicenseDetail --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "d09cfcae-fab2-4cb7-a41e-5fd4c12d69f4",
        "DownloadUrl": "",
        "TaskId": 1
    }
}
```

